@@ -104,6 +104,8 @@ def grid2points2(arr, lons, lats, lon_pnts, lat_pnts, missing = -9999, method =
 def points2grid(data, lons, lats, missing = -9999, method = 'nearest'):
     uniqueLats = np.unique(lats)
     uniqueLons = np.unique(lons)
+    if uniqueLats[0] < uniqueLats[-1]: uniqueLats = np.flip(uniqueLats) 
+    # uniqueLats = uniqueLats[::-1] # lats shoud be descending from upper to bottom
 
     if missing: data[np.where(data == missing)] = np.nan
     points = list(zip(lons, lats))
@@ -121,7 +123,7 @@ def points2points(data, lons_orig, lats_orig, lons_tar, lats_tar):
     return interp(lons_tar, lats_tar)
 
 def latex_float(f):
-    if (f < 0.01) or (f > 100):
+    if (np.abs(f) != 0) & ((np.abs(f) < 0.01) or (np.abs(f) > 100)):
         float_str = "{0:.2e}".format(f)
     else:
         float_str = "{0:.2g}".format(f)
@@ -158,4 +160,4 @@ def map2darr(arr, uniqueLons, uniqueLats, unit = "", cmap = "viridis", figsize =
     ax.set_xlabel("Longitude")
     ax.set_ylabel("Latitude")
 
-    return fig
\ No newline at end of file
+    return fig, ax
\ No newline at end of file
